SystemOrganization addCategory: #'ConfigurationOfXMLSupport'!

Object subclass: #ConfigurationOfXMLSupport
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfXMLSupport'!

!ConfigurationOfXMLSupport class methodsFor: 'private' stamp: 'DaleHenrichs 2/7/2010 09:39'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfXMLSupport class methodsFor: 'private' stamp: 'DaleHenrichs 2/7/2010 09:39'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
			self bootstrapPackage: 'Gofer-Core-lr.115' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load 'default' group of Metacello"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #load ]! !

!ConfigurationOfXMLSupport class methodsFor: 'metacello tool support' stamp: 'DaleHenrichs 2/7/2010 09:39'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfXMLSupport class methodsFor: 'metacello tool support' stamp: 'DaleHenrichs 2/7/2010 09:39'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfXMLSupport class methodsFor: 'loading' stamp: 'Alexandre Bergel 2/24/2010 08:33'!
load
	"self load"

	^self project lastVersion load! !

!ConfigurationOfXMLSupport class methodsFor: 'loading' stamp: 'Alexandre Bergel 2/24/2010 08:34'!
loadDefault
	"self load"

	^ self load! !

!ConfigurationOfXMLSupport class methodsFor: 'metacello tool support' stamp: 'DaleHenrichs 2/7/2010 09:39'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfXMLSupport class methodsFor: 'accessing' stamp: 'DaleHenrichs 2/7/2010 09:39'!
project

	^self new project! !

!ConfigurationOfXMLSupport class methodsFor: 'unloading Metacello' stamp: 'DaleHenrichs 2/7/2010 09:39'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfXMLSupport methodsFor: 'baselines' stamp: 'DaleHenrichs 2/7/2010 09:49'!
baseline100: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/XMLSupport'.	
		spec 
			package: 'XML-Parser'.
		spec
			group: 'default' with: #('Core');
			group: 'Core' with: #('XML-Parser');
			group: 'Tests' with: #(). ].! !

!ConfigurationOfXMLSupport methodsFor: 'baselines' stamp: 'DaleHenrichs 03/03/2010 16:10'!
baseline101: spec 
	<version: '1.0.1-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/XMLSupport'.	
		spec
			group: 'default' with: #('Core');
			group: 'Core' with: #('XML-Parser');
			group: 'Tests' with: #(). ].
	spec for: #squeakCommon do: [
		spec repository: 'http://www.squeaksource.com/XMLSupport'.
		spec 
			package: 'XML-Parser'. ].
	spec for: #gemstone do: [
		spec
			project: 'XML-Parser' with: [
				spec
					className: 'ConfigurationOfGsMisc';
					loads: #('XML-Parser');
					file: 'ConfigurationOfGsMisc';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			yourself.].! !

!ConfigurationOfXMLSupport methodsFor: 'accessing' stamp: 'DaleHenrichs 2/7/2010 09:39'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfXMLSupport methodsFor: 'versions' stamp: 'DaleHenrichs 2/7/2010 09:49'!
version100: spec 
	<version: '1.0' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec 
			package: 'XML-Parser' with: 'XML-Parser-Alexandre_Bergel.20']! !

!ConfigurationOfXMLSupport methodsFor: 'versions' stamp: 'Alexandre Bergel 2/24/2010 08:33'!
version101: spec 
	<version: '1.0.1' imports: #('1.0.1-baseline') >
	
	spec for: #common do: [
		spec blessing: #development. ].
	spec for: #squeakCommon do: [
		spec 
			package: 'XML-Parser' with: 'XML-Parser-Alexandre_Bergel.20'].
	spec for: #gemstone do: [
		spec 
			project: 'XML-Parser' with: '0.235'].! !

!ConfigurationOfXMLSupport methodsFor: 'versions' stamp: 'Alexandre Bergel 5/21/2010 16:47'!
version102: spec 
	<version: '1.0.3' imports: #('1.0.1-baseline') >
	"Note that this version is evolving. All future improvement of the version 1.0.2 should be backward compatible."
	
	spec for: #common do: [
		spec blessing: #development. ].
	spec for: #squeakCommon do: [
		spec 
			package: 'XML-Parser' with: 'XML-Parser-Alexandre_Bergel.78'].
	spec for: #gemstone do: [
		spec 
			project: 'XML-Parser' with: '0.236' "port of XML-Parser-Alexandre_Bergel.41"].! !
